pub fn read_benchmark_bundle(path: impl AsRef<Path>) -> Result<BenchmarkBundle>Expand description
Verifies and reopens a complete benchmark bundle and its nested result manifests.
pub fn read_benchmark_bundle(path: impl AsRef<Path>) -> Result<BenchmarkBundle>Verifies and reopens a complete benchmark bundle and its nested result manifests.